#!/usr/bin/python

"""

	MobileMail

	Reads a series of IMAP mailboxes and outputs 
	the from and subject lines of the last emails 
	(configurable) with links to read the emails 
	as plain text.

	For each email listed, a cache of it is written
	to /tmp for speed.

	Existing cache files are deleted prior to the
	list being output.

	25 Apr RRT - Support for showing arrival date

"""
__author__ = "Robin Rawson-Tetley <robin@rawsontetley.org>"
__version__ = "1.01"
__license__ = "GPL"
__copyright__ = "Copyright(c)2005, Robin Rawson-Tetley"
__date__ = "25th April, 2005"

import os
import re
import imaplib
import config

# Output the header of the HTML page
print "Content-type: text/html"
print ""
print "<html><body><h1>Mail</h1>"
print "<p><a href='status.html'>back</a></p>"

# Make sure the tmp directory doesn't end with a trailing slash
if config.tmpdir.endswith("/"):
	config.tmpdir = config.tmpdir[0:len(config.tmpdir)-1]
	
# Destroy existing temp files
for tmpf in os.listdir(config.tmpdir):
	if tmpf.startswith("msg_"):
		os.remove(config.tmpdir + "/" + tmpf)

# Precompile our two regular expression matches
# to read the From and Subject lines from emails
frompattern = re.compile("From:.*")
subjectpattern = re.compile("Subject:.*")
datepattern = re.compile("Date:.*")

# Login to the IMAP server using appropriate imap/s
if config.usessl == 1:
	M = imaplib.IMAP4_SSL(config.host)
else:
	M = imaplib.IMAP4(config.host)
	
M.login(config.user, config.password)

# Loop through the chosen boxes, outputting links
# for the last x mails
curbox = 0
for mbox in config.mboxes:

	# If an empty string is supplied, then
	# terminate
	if (mbox == ""):
		break
	else:
		M.select(mbox)
	
	print "<h2>" + mbox + "</h2>"
	
	# Do an IMAP search for all messages in the box
	typ, data = M.search(None, 'ALL')

	# We want the last "maxdisplay" messages
	count = 0
	for num in reversed(data[0].split()):
		typ, data = M.fetch(num, '(RFC822)')
		
		# Extract the from line
		msg = data[0][1]
		for i in frompattern.findall(msg):
			fr = i
			# Sanitise email address quoting angle brackets
			# so they don't upset the XHTML output by
			# converting them to regular parentheses
			fr = fr.replace("<", "(")
			fr = fr.replace(">", ")")
			# Chop off the From: bit
			fr = fr[6:len(fr)]
			break
			
		# And the subject line
		for i in subjectpattern.findall(msg):
			subject = i[9:len(i)]
			break

		# And the date
		for i in datepattern.findall(msg):
			arrivaldate = i[6:len(i)]
			break

		# Generate a temporary file in /tmp with the
		# pattern msg_[boxnumber]_[msgnumber] containing
		# the message
		cachefile = "msg_" + str(curbox) + "_" + str(num)
		f = open("/tmp/" + cachefile, "w")
		f.write(msg)
	
		# Output a link
		print "<p>%s<br/>%s<br/><a href='readmail.cgi?%s'>%s</a><hr/></p>" % ( arrivaldate, fr, cachefile, subject )
	
		# Shown enough messages?
		count = count + 1
		if count > config.maxdisplay:
			break

	# Next box
	curbox = curbox + 1

# Disconnect from the IMAP server
M.close()
M.logout()

# Output a form for sending email
print "<form name='s1' id='s1' method='get' action='sendmail.cgi'><h1>Send</h1>"
print "<p>To:<br/><input id='to' name='to' type='text' /></p>"
print "<p>Subject:<br/><input id='subject' name='subject' type='text' /></p>"
print "<p><textarea id='body' name='body'></textarea><br />"
print "<input type='submit' name='submit' value='Send'></p>"
print "</form>"
print "</body></html>"
	
